<?php
/** N'Ko (ߒߞߏ)
 *
 * @file
 * @ingroup Languages
 */

$rtl = true;

$namespaceNames = [
	NS_MEDIA            => 'ߟߊߛߋߢߊߥߙߍ',
	NS_SPECIAL          => 'ߞߙߍߞߙߍߣߍ߲',
	NS_TALK             => 'ߢߊߝߐߞߣߍ',
	NS_USER             => 'ߟߊߓߊ߯ߙߟߊ',
	NS_USER_TALK        => 'ߟߊߓߊ߯ߙߟߊ_ߟߊ߫_ߢߊߝߐߞߣߍ',
	NS_PROJECT_TALK     => '$1_ߢߊߝߐߞߣߍ',
	NS_FILE             => 'ߞߐߕߐ߮',
	NS_FILE_TALK        => 'ߞߐߕߐ߮_ߢߊߝߐߞߣߍ',
	NS_MEDIAWIKI        => 'ߡߘߌߦߊߥߞߌ',
	NS_MEDIAWIKI_TALK   => 'ߡߘߌߦߊߥߞߌ_ߢߊߝߐߞߣߍ',
	NS_TEMPLATE         => 'ߞߙߊߞߏ',
	NS_TEMPLATE_TALK    => 'ߞߙߊߞߏ_ߢߊߝߐߞߣߍ',
	NS_HELP             => 'ߡߊ߬ߘߍ߬ߡߍ߲߬ߠߌ߲',
	NS_HELP_TALK        => 'ߡߊ߬ߘߍ߬ߡߍ߲߬ߠߌ߲_ߢߊߝߐߞߣߍ',
	NS_CATEGORY         => 'ߦߌߟߡߊ',
	NS_CATEGORY_TALK    => 'ߦߌߟߡߊ_ߢߊߝߐߞߣߍ',
];

$digitTransformTable = [
	'0' => '߀', # U+07C0
	'1' => '߁', # U+07C1
	'2' => '߂', # U+07C2
	'3' => '߃', # U+07C3
	'4' => '߄', # U+07C4
	'5' => '߅', # U+07C5
	'6' => '߆', # U+07C6
	'7' => '߇', # U+07C7
	'8' => '߈', # U+07C8
	'9' => '߉', # U+07C9
];

$numberingSystem = 'nkoo';
